==> eleme-openapi-sdk-1.30.71-sources.jar: eleme/openapi/sdk/api/entity/shop/DyCallBackEleDto.java <==
package eleme.openapi.sdk.api.entity.shop;

import java.util.*;

public class DyCallBackEleDto{

    /**
     * 饿侧ID
     */
    private String ele_id;
    public String getEle_id() {
        return ele_id;
    }
    public void setEle_id(String ele_id) {
        this.ele_id = ele_id;
    }
    
    /**
     * 回调类型
     */
    private Integer type;
    public Integer getType() {
        return type;
    }
    public void setType(Integer type) {
        this.type = type;
    }
    
    /**
     * dyId
     */
    private String dy_id;
    public String getDy_id() {
        return dy_id;
    }
    public void setDy_id(String dy_id) {
        this.dy_id = dy_id;
    }
    
    /**
     * 聚合状态
     */
    private String dy_aggr_status;
    public String getDy_aggr_status() {
        return dy_aggr_status;
    }
    public void setDy_aggr_status(String dy_aggr_status) {
        this.dy_aggr_status = dy_aggr_status;
    }
    
    /**
     * dy状态
     */
    private String dy_status;
    public String getDy_status() {
        return dy_status;
    }
    public void setDy_status(String dy_status) {
        this.dy_status = dy_status;
    }
    
    /**
     * dy状态描述
     */
    private String dy_status_desc;
    public String getDy_status_desc() {
        return dy_status_desc;
    }
    public void setDy_status_desc(String dy_status_desc) {
        this.dy_status_desc = dy_status_desc;
    }
    
    /**
     * dy回调给商家指示
     */
    private String dy_hint;
    public String getDy_hint() {
        return dy_hint;
    }
    public void setDy_hint(String dy_hint) {
        this.dy_hint = dy_hint;
    }
    
    /**
     * 版本号毫秒
     */
    private Long version;
    public Long getVersion() {
        return version;
    }
    public void setVersion(Long version) {
        this.version = version;
    }
    
    /**
     * 扩展信息
     */
    private Map<String,String> extend_info;
    public Map<String,String> getExtend_info() {
        return extend_info;
    }
    public void setExtend_info(Map<String,String> extend_info) {
        this.extend_info = extend_info;
    }
    
}

==> eleme-openapi-sdk-1.31.37-sources.jar: eleme/openapi/sdk/api/entity/shop/DyCallBackEleDto.java <==
package eleme.openapi.sdk.api.entity.shop;

import eleme.openapi.sdk.api.enumeration.shop.*;
import eleme.openapi.sdk.api.entity.shop.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class DyCallBackEleDto{

    /**
     * 饿侧ID
     */
    private String ele_id;
    public String getEle_id() {
        return ele_id;
    }
    public void setEle_id(String ele_id) {
        this.ele_id = ele_id;
    }
    
    /**
     * 回调类型
     */
    private Integer type;
    public Integer getType() {
        return type;
    }
    public void setType(Integer type) {
        this.type = type;
    }
    
    /**
     * dyId
     */
    private String dy_id;
    public String getDy_id() {
        return dy_id;
    }
    public void setDy_id(String dy_id) {
        this.dy_id = dy_id;
    }
    
    /**
     * 聚合状态
     */
    private String dy_aggr_status;
    public String getDy_aggr_status() {
        return dy_aggr_status;
    }
    public void setDy_aggr_status(String dy_aggr_status) {
        this.dy_aggr_status = dy_aggr_status;
    }
    
    /**
     * dy状态
     */
    private String dy_status;
    public String getDy_status() {
        return dy_status;
    }
    public void setDy_status(String dy_status) {
        this.dy_status = dy_status;
    }
    
    /**
     * dy状态描述
     */
    private String dy_status_desc;
    public String getDy_status_desc() {
        return dy_status_desc;
    }
    public void setDy_status_desc(String dy_status_desc) {
        this.dy_status_desc = dy_status_desc;
    }
    
    /**
     * dy回调给商家指示
     */
    private String dy_hint;
    public String getDy_hint() {
        return dy_hint;
    }
    public void setDy_hint(String dy_hint) {
        this.dy_hint = dy_hint;
    }
    
    /**
     * 版本号毫秒
     */
    private Long version;
    public Long getVersion() {
        return version;
    }
    public void setVersion(Long version) {
        this.version = version;
    }
    
    /**
     * 扩展信息
     */
    private Map<String,String> extend_info;
    public Map<String,String> getExtend_info() {
        return extend_info;
    }
    public void setExtend_info(Map<String,String> extend_info) {
        this.extend_info = extend_info;
    }
    
}
